[![CircleCI](https://circleci.com/gh/ylathouris/bio.svg?style=shield)](https://circleci.com/gh/ylathouris/rolodex)  ![Coverage](coverage.svg)

---

# Cuta

Cuta is a set of tools designed to make building applications easier.


<br/>

## Next Steps

* [Installation](docs/installation.md)
* [Quick Start](docs/quickstart.md)

<br/>


[Docker]: https://www.docker.com/
[Terraform]: https://www.terraform.io/